=====
admin
=====


.. automodule:: camelot.admin
   :members:

.. toctree::

   action/index.rst
   application_admin.rst
   entity_admin.rst
   not_editable_admin.rst
   object_admin.rst
   section.rst
   validator/index.rst
